#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 17-2-21
# @Author  : JCai
# @desc    :


from datetime import datetime
from django.db.models import Q
from django.utils import timezone

from order_statistic.models import SkuDaysStatistic, SpuDaysStatistic
from sale_aliexpress.utils import get_dict_from_object
from starpro.utils import json_encode
from sysproduct.models import Category, ProjectTeamUser, SpuProduct, SkuProduct, ProjectTeam
from sysproduct.models.product import SaleSpuProduct
from warehouse.models import SpuInventory, SkuInventory,SkuWarehouseInventory,Warehouse
import time
from sysproduct.models import SpuComment


def brow_products_sku(edit_info, user_id, position=''):
    if position == 'manager':
        project_code = edit_info.get('projectCode', '')
        if project_code:
            spu_products = SpuProduct.objects\
                .filter(project_team_id__in=[project_code], push_state=1) \
                .order_by('-create_date')
            products = SkuProduct.objects\
                .filter(spu__project_team_id__in=[project_code], spu__push_state=1) \
                .order_by('-create_date')
        else:
            spu_products = SpuProduct.objects\
                .filter(push_state=1) \
                .order_by('-create_date')
            products = SkuProduct.objects\
                .filter(spu__push_state=1) \
                .order_by('-create_date')
    else:
        teams = ProjectTeamUser.objects.filter(user_id=user_id)
        project_code = edit_info.get('projectCode', '')
        if project_code:
            team_info = ProjectTeam.objects.filter(id=project_code, state=0).first()
            if not team_info:
                products = SkuProduct.objects.filter()
                spu_products = SpuProduct.objects.filter()
                cate_data = SaleSpuProduct.get_category_products_count(spu_products)
                return {'rows': [], 'total': 0, 'cate_data': cate_data}

            spu_products = SpuProduct.objects\
                .filter(project_team_id__in=[project_code], push_state=1) \
                .order_by('-create_date')
            products = SkuProduct.objects\
                .filter(spu__project_team_id__in=[project_code], spu__push_state=1) \
                .order_by('-create_date')
        else:
            team_nums = ProjectTeam.objects.filter(id__in=[x.team_id for x in teams], state=0)
            spu_products = SpuProduct.objects\
                .filter(project_team_id__in=[x.id for x in team_nums], push_state=1,
                        sale_ok = 1, purchase_ok = 1) \
                .order_by('-create_date')
            products = SkuProduct.objects\
                .filter(spu__project_team_id__in=[x.id for x in team_nums], spu__push_state=1,
                        sale_ok = 1, purchase_ok = 1) \
                .order_by('-create_date')

    product_search = edit_info.get('product', '')
    if product_search == '1':
        day_now = timezone.now()
        start_date = day_now - timezone.timedelta(hours=day_now.hour, minutes=day_now.minute,
                                                 seconds=day_now.second, microseconds=day_now.microsecond)
        day_end = start_date + timezone.timedelta(hours=23, minutes=59, seconds=59, microseconds=999999)
        day_start = start_date + timezone.timedelta(days=-29)
        spu_products = spu_products.filter(create_date__range=(day_start, day_end))
        products = products.filter(create_date__range=(day_start, day_end))
    elif product_search == '4':
        spu_products = spu_products.filter(product_level=6)
        products = products.filter(product_level=6)
    elif product_search == '5':
        products_comment_spu = SpuComment.objects.values_list('spu',flat=True).distinct()
        products = products.filter(spu_code__in=products_comment_spu)
        spu_products=spu_products.filter(spu__in=products_comment_spu)

    developer_type = edit_info.get('type', '')
    if developer_type != '':
        spu_products = spu_products.filter(developer_type=developer_type)
        products = products.filter(spu__developer_type=developer_type)

    product_key = edit_info.get('title', '').strip()# 全局
    if product_key:
        search_type = edit_info.get('searchStatus', 'searchLike')
        if search_type == 'searchLike':  # 模糊查询条件
            if product_key > u'\u4e00' and product_key < u'\u9fa5':
                spu_products = spu_products.filter(chinese_title__icontains=product_key)
                products = products.filter(spu__chinese_title__icontains=product_key)
            else:
                spu_products = spu_products.filter(Q(spu__icontains=product_key)
                                           | Q(chinese_title__icontains=product_key)
                                           | Q(title__icontains=product_key))
                products = products.filter(Q(spu_code__icontains=product_key)
                                           | Q(spu__chinese_title__icontains=product_key)
                                           | Q(spu__title__icontains=product_key))

        elif search_type == 'nameCNLike':  # 按中文名称
            spu_products = spu_products.filter(chinese_title__icontains=product_key)
            products = products.filter(spu__chinese_title__icontains=product_key)
        elif search_type == 'nameENLike':  # 按英文名称
            spu_products = spu_products.filter(title__icontains=product_key)
            products = products.filter(spu__title__icontains=product_key)
        elif search_type == 'virtualSpu':  # 按虚拟SPU
            products = spu_products.filter(spu__icontains=product_key)
        elif search_type == 'virtualSku':  # 按虚拟SKU
            # product_key = edit_info.get('title', '').strip().replace(' ','').split(',')  #
            product_key = edit_info.get('title', '').split(' ')
            product_key_list = []
            for tem_product_key in product_key:
                tem_product_key = tem_product_key.strip()
                product_key_list.append(tem_product_key)
            sku_obj = SkuProduct.objects.filter(sku__in=product_key_list).exclude(product_lifecycle=4)
            #sku_obj = SkuProduct.objects.filter(sku=product_key).exclude(product_lifecycle=4).first()
            products = products.filter(sku__in = product_key_list)
            if sku_obj:
                spu_code_list=[]
                for tem_sku_obj in sku_obj:
                    spu_code_list.append(tem_sku_obj.spu_code)
                spu_products = spu_products.filter(spu__in = spu_code_list)
            else:
                spu_products = SpuProduct.objects.none()

    daterange = edit_info.get('daterange', None)
    if daterange:
        dateranges = str(daterange).split(' to ')
        if len(dateranges) >= 2:
            start_date = datetime.strptime(dateranges[0], '%Y-%m-%d')
            end_date = datetime.strptime(dateranges[1], '%Y-%m-%d')
            spu_products = spu_products.filter(create_date__range=(start_date, end_date))
            products = products.filter(create_date__range=(start_date, end_date))


    category_select = edit_info.get('cate_id', '')
    limit = int(edit_info.get('limit', '50'))
    offset = int(edit_info.get('offset', '0'))
    if offset == 0:
        cate_data = SaleSpuProduct.get_category_products_count(spu_products)
    else:
        cate_data = []
    if category_select:
        cate = Category.objects.filter(id=category_select).first()
        products = products.filter(
            spu__category_id_path__startswith=cate.category_id_path + '>' + category_select + '>' if cate.category_id_path != '0' else category_select + '>')

    day_now = timezone.now()
    start_date = day_now - timezone.timedelta(hours=day_now.hour, minutes=day_now.minute,
                                              seconds=day_now.second, microseconds=day_now.microsecond)
    day_end = start_date + timezone.timedelta(hours=23, minutes=59, seconds=59, microseconds=999999)
    day_start = start_date + timezone.timedelta(days=-29)
    #end_timestamp = time.mktime(time.strptime(str(day_end)[:19], '%Y-%m-%d %H:%M:%S'))
    #start_timestamp = time.mktime(time.strptime(str(day_start)[:19], '%Y-%m-%d %H:%M:%S'))

    total = products.count()
    items = []
    for _item in products[offset:offset + limit]:
        _info = {}
        _info['projectCode'] = _item.spu.project_code
        _info['spu'] = _item.spu_code
        _info['sku'] = _item.sku
        _info['title'] = _item.spu.title
        _info['chinese_title'] = _item.spu.chinese_title
        _info['gross_weight'] = _item.gross_weight
        _info['product_level'] = _item.product_level
        _info['product_lifecycle'] = _item.product_lifecycle
        _info['price'] = _item.spu.price
        _info['create_date'] = eval(json_encode(_item.create_date))

        #product_flag = []
        #create_date_timestamp = time.mktime(time.strptime(str(_info['create_date'])[:19], '%Y-%m-%d %H:%M:%S'))
        #if create_date_timestamp > start_timestamp and create_date_timestamp < end_timestamp:
        #    product_flag.append(1)
        #else:
        #    product_flag.append(0)
        #if _item.product_level == 6:
        #    product_flag.append(1)
        #else:
        #    product_flag.append(0)
        #_info['product_flag'] = product_flag

        try:
            _info['product_manager'] = _item.spu.product_manager.get_cn_full_name() if _item.product_manager else ''
        except:
            _info['product_manager'] = '--'

        _info['main_image'] = _item.main_image

        try:
            sku_inventory = SkuInventory.objects.filter(sku_id__sku=_item.sku).first()
        except:
            sku_inventory = ''
            pass
        if sku_inventory:
            _info['sz'] = sku_inventory.sz_on_hand
            _info['us'] = sku_inventory.mg_on_hand
            statistic_month_sku = SkuDaysStatistic.objects.filter(sku=sku_inventory.sku_id.id).first()
            if statistic_month_sku:
                _info['month'] = statistic_month_sku.month_qty


        items.append(_info)

    return {'rows': items, 'total': total, 'cate_data': cate_data}

